set_form_variables 0

# answer_id

set headers [ns_conn headers $conn]
set cookie [ns_set get $headers Cookie]
if { ![regexp {player_id=([^;]+)} $cookie {} player_id] } {
    ns_return 200 text/html "no cookie :-( "
    return
}

# we have player_id set appropriately

set db [ns_db gethandle clickpool]

set selection [ns_db 0or1row $db "select * from players where player_id = $player_id"]

if { $selection == "" } {
    ns_return 200 text/html "no entry in the RDBMS :-( "
    return
}

# we have a row from the database, now turn the columns into Tcl local
# variables

set_variables_after_query

# going to use quiz_id, questions_answered, score

# process answer to previous question

set reanswering_note ""

if { [info exists answer_id] } {
    set selection [ns_db 1row $db "select question_id as corresponding_question_id, score_delta from answers where answer_id = $answer_id"]
    set_variables_after_query
    if { [lsearch $questions_answered $corresponding_question_id] == -1 } {
	# we only do something if the question wasn't answered already
	set current_score [expr $score + $score_delta]
	ns_db dml $db "update players 
set questions_answered = '[lappend questions_answered $corresponding_question_id]',
score = $current_score
where player_id = $player_id"
        ns_db dml $db "update answers set responses = responses + 1 where answer_id = $answer_id"
       set next_question_id [database_to_tcl_string $db "select next_question_id from questions where question_id = $corresponding_question_id"]
   } else {
       # re-answering a question
       set next_question_id [database_to_tcl_string $db "select next_question_id from questions where question_id = $corresponding_question_id"]
       set current_score $score
       set reanswering_note "<p>(not updated because you already answered the previous question)"
   }
} else {
    # not answering a question (presumably this is the first iteration)
    # set score according to what was in the database (presumably the
    # default value of 15)
    set current_score $score
    if { $questions_answered == "" } {
	# we're on the very first question
	set next_question_id [database_to_tcl_string $db "select first_question_id from quizzes where quiz_id = $quiz_id"]
    } else {
	# we will only get to this code if the user backs up to the very
	# first question.tcl (with no form vars)
	set last_question_id [lindex $questions_answered [expr [llength $questions_answered]-1]]
	set next_question_id [database_to_tcl_string $db "select next_question_id from questions where question_id = $last_question_id"]
    }
}


if { $next_question_id == "" } {
    # there are no more questions
    ns_returnredirect final-score.tcl?reason=no_more_questions
    return
}

set selection [ns_db 1row $db "select preamble, text as question_text, min_image_number, max_image_number
from questions, quizzes
where question_id = $next_question_id
and questions.quiz_id = quizzes.quiz_id"]
set_variables_after_query

# we know the max possible score now, so let's check to see if this
# guy should be bounced

if { $current_score >= $max_image_number } {
    ns_returnredirect final-score.tcl?reason=player_won
    return
}


# we assume that we have integer images in the /images/**quiz_id**/ dir named
# 0.2.jpg through 30.2.jpg (these will be the 2nd PhotoCD resolution, 
# i.e, 256x384

# each image will be a hyperlink to bigger.tcl?quiz_id=n&image_number=m
# the bigger.tcl file will display the .3 PhotoCD res and offer a hyperlink
# to the .4 res.

# < min we round up to min; > max and we SHOULD say that they won but we 
# don't right now because we're lazy

set image_number [expr round($current_score)]
if { $image_number < $min_image_number } {
    set image_number $min_image_number
} 
if { $image_number > $max_image_number } {
    set image_number $max_image_number
}

if { $preamble == "" } {
    set full_blurb $question_text
} else {
    set full_blurb "$preamble\n<br><br>\n$question_text"
}

ReturnHeadersNoCache

ns_write "<html>
<head>
<title>$question_text</title>
</head>

<body bgcolor=#ffffff text=#000000>



<center>

<a target=bigpicture href=\"bigger.tcl?quiz_id=$quiz_id&image_number=$image_number\">
<img border=0 src=\"images/$quiz_id/$image_number.2.jpg\">
</a>

<h3>$full_blurb</h3>

</center>

<blockquote>

<ul>

"

set selection [ns_db select $db "select answer_id, text as answer_text
from answers 
where question_id = $next_question_id"]

while { [ns_db getrow $db $selection] } {
    set_variables_after_query
    ns_write "<p><li><a href=\"question.tcl?answer_id=$answer_id\">$answer_text</a>\n"
}

ns_write "

</ul>
</blockquote>

<center>

<h3>Your current score:  $current_score</h3>

$reanswering_note

</center>



<hr>

<a href=index.tcl>The Game</a>

</body>
</html>"
